@@ -21,7 +21,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02110-1301, USA.
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  */
 
@@ -185,7 +185,7 @@ click_help_cb (GtkWidget * widget,
 	GtkWidget * window = data;
 	GError * error = NULL;
 
-	gtk_show_uri (gtk_widget_get_screen (widget), "ghelp:mate-search-tool",  
+	gtk_show_uri (gtk_widget_get_screen (widget), "help:mate-search-tool",  
 	              gtk_get_current_event_time (), &error);
 	if (error) {
 		GtkWidget * dialog;
